==> openshift-model-operator-6.7.2-sources.jar: io/fabric8/openshift/api/model/operator/v1/UpstreamBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class UpstreamBuilder extends UpstreamFluentImpl<UpstreamBuilder> implements VisitableBuilder<Upstream,UpstreamBuilder>{
  public UpstreamBuilder() {
    this(false);
  }
  public UpstreamBuilder(Boolean validationEnabled) {
    this(new Upstream(), validationEnabled);
  }
  public UpstreamBuilder(UpstreamFluent<?> fluent) {
    this(fluent, false);
  }
  public UpstreamBuilder(UpstreamFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Upstream(), validationEnabled);
  }
  public UpstreamBuilder(UpstreamFluent<?> fluent,Upstream instance) {
    this(fluent, instance, false);
  }
  public UpstreamBuilder(UpstreamFluent<?> fluent,Upstream instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withAddress(instance.getAddress());
      fluent.withPort(instance.getPort());
      fluent.withType(instance.getType());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public UpstreamBuilder(Upstream instance) {
    this(instance,false);
  }
  public UpstreamBuilder(Upstream instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withAddress(instance.getAddress());
      this.withPort(instance.getPort());
      this.withType(instance.getType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  UpstreamFluent<?> fluent;
  Boolean validationEnabled;
  public Upstream build() {
    Upstream buildable = new Upstream(fluent.getAddress(),fluent.getPort(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-operator-6.8.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/UpstreamBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class UpstreamBuilder extends UpstreamFluent<UpstreamBuilder> implements VisitableBuilder<Upstream,UpstreamBuilder>{
  public UpstreamBuilder() {
    this(false);
  }
  public UpstreamBuilder(Boolean validationEnabled) {
    this(new Upstream(), validationEnabled);
  }
  public UpstreamBuilder(UpstreamFluent<?> fluent) {
    this(fluent, false);
  }
  public UpstreamBuilder(UpstreamFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Upstream(), validationEnabled);
  }
  public UpstreamBuilder(UpstreamFluent<?> fluent,Upstream instance) {
    this(fluent, instance, false);
  }
  public UpstreamBuilder(UpstreamFluent<?> fluent,Upstream instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new Upstream());

    if (instance != null) {
      fluent.withAddress(instance.getAddress());
      fluent.withPort(instance.getPort());
      fluent.withType(instance.getType());
      fluent.withAddress(instance.getAddress());
      fluent.withPort(instance.getPort());
      fluent.withType(instance.getType());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public UpstreamBuilder(Upstream instance) {
    this(instance,false);
  }
  public UpstreamBuilder(Upstream instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new Upstream());

    if (instance != null) {
      this.withAddress(instance.getAddress());
      this.withPort(instance.getPort());
      this.withType(instance.getType());
      this.withAddress(instance.getAddress());
      this.withPort(instance.getPort());
      this.withType(instance.getType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  UpstreamFluent<?> fluent;
  Boolean validationEnabled;
  public Upstream build() {
    Upstream buildable = new Upstream(fluent.getAddress(),fluent.getPort(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
